@@ -388,7 +388,8 @@ def thread_safe_pydal_patch():
         "represent",
     ]
     for a in tsafe_attrs:
-        setattr(Field, a, threadsafevariable.ThreadSafeVariable())
+        b = threadsafevariable.ThreadSafeVariable()
+        setattr(Field, a, b)
 
     # hack 'copy.copy' behavior, since it makes a shallow copy,
     # but ThreadSafe-attributes (see above) are class-level, so:
@@ -937,7 +938,7 @@ class action:
         """Building the decorator"""
         app_name = action.app_name
         if self.path[0] == "/":
-            path = self.path.rstrip("/")
+            path = self.path.rstrip("/") or "/"
         else:
             if app_name == "_default":
                 base_path = ""
@@ -1769,9 +1770,11 @@ def call(apps_folder, func, yes, args):
     kwargs = json.loads(args)
     install_args(dict(apps_folder=apps_folder, yes=yes))
     apps_folder_name = os.path.basename(os.environ["PY4WEB_APPS_FOLDER"])
+    app_name = func.split('.')[0]
     module, name = ("%s.%s" % (apps_folder_name, func)).rsplit(".", 1)
     env = {}
     exec("from %s import %s" % (module, name), {}, env)
+    request.app_name = app_name
     env[name](**kwargs)
 
 
